@@ -242,14 +242,14 @@ WirelessSecurityWEPImpl::getHashedWEPKey(TQString key, WEPKEY_TYPE type) const
 	switch(type)
 	{
 		case WEPKEY_TYPE_HEX:
-			return TQCString(key);
+			return TQCString(key.latin1());
 			break;
 		case WEPKEY_TYPE_ASCII:
-			hashed = String2Hex(TQCString(key), key.length() * 2);
+			hashed = String2Hex(TQCString(key.latin1()), key.length() * 2);
 			return hashed;
 			break;
 		case WEPKEY_TYPE_PASSPHRASE:
-			return TQCString(key);
+			return key.utf8();
 			break;
 	}
 	return hashed;
