@@ -128,7 +128,7 @@ void DeviceTrayComponent::deviceEventHandler(TDENetworkDeviceEventType::TDENetwo
 	kdDebug() << "DeviceTrayComponent::deviceEventHandler" << endl;
 
 	if (event == TDENetworkDeviceEventType::Failure) {
-		KNotifyClient::event( tray()->winId(), "tdenm-nm-connection-attempt-failed", i18n(message) );
+		KNotifyClient::event( tray()->winId(), "tdenm-nm-connection-attempt-failed", i18n(message.utf8()) );
 	}
 }
 
