@@ -266,10 +266,13 @@ void WirelessDeviceTray::addMenuItems(TDEPopupMenu* menu)
 	Subhead* subhead = new Subhead (menu, "subhead", TQString("Wireless Connection (%1)").arg(dev->deviceNode()), SmallIcon("wireless", TQIconSet::Automatic));
 	menu->insertItem (subhead, -1, -1);
 
-	// bolding subhead instead
-	//menu->insertSeparator();
-
-	if (!nm->wiFiEnabled())
+	TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
+	if (!deviceConnMan->deviceInformation().managed) {
+		// device is not managed by NM -> do not show any connections
+		subhead = new Subhead(menu, "subhead2", i18n("Not managed"), SmallIcon("no", TQIconSet::Automatic));
+		menu->insertItem(subhead, -1, -1);
+	}
+	else if (!nm->wiFiEnabled())
 	{
 		// wireless disabled -> do not show any connections
 		subhead = new Subhead(menu, "subhead2", i18n("Wireless disabled"), SmallIcon("no", TQIconSet::Automatic));
